@@ -15,55 +15,59 @@
   global R variables 
 ============================================================================*/
 
-double *timesteps; /* see also: R_init_deSolve.c */
+#ifndef EXTERN
+# define EXTERN extern
+#endif
 
-SEXP YOUT, YOUT2, ISTATE, RWORK, IROOT;    /* returned to R */
-SEXP Y, YPRIME , Rin;
+EXTERN double *timesteps; /* see also: R_init_deSolve.c */
 
-int     n_eq; 
+EXTERN SEXP YOUT, YOUT2, ISTATE, RWORK, IROOT;    /* returned to R */
+EXTERN SEXP Y, YPRIME , Rin;
+
+EXTERN int     n_eq; 
 
 
 /* use in daspk */
-long int nrowpd;
+EXTERN long int nrowpd;
 
 /* output in DLL globals */
-int  isOut, *ipar;
-double *out;
+EXTERN int  isOut, *ipar;
+EXTERN double *out;
 
 /* forcings  */
-long int nforc;  /* the number of forcings */
-double *tvec;
-double *fvec;
-int    *ivec;
-int    fmethod;
+EXTERN long int nforc;  /* the number of forcings */
+EXTERN double *tvec;
+EXTERN double *fvec;
+EXTERN int    *ivec;
+EXTERN int    fmethod;
 
-int    *findex;
-double *intpol;
-int    *maxindex;
+EXTERN int    *findex;
+EXTERN double *intpol;
+EXTERN int    *maxindex;
 
-double *forcings;
+EXTERN double *forcings;
 
 /* events */
-double tEvent;
-int iEvent, nEvent, typeevent, rootevent, Rootsave;
-double *troot, *valroot;
-int *nrroot, *termroot;
+EXTERN double tEvent;
+EXTERN int iEvent, nEvent, typeevent, rootevent, Rootsave;
+EXTERN double *troot, *valroot;
+EXTERN int *nrroot, *termroot;
 
-double *timeevent, *valueevent;
-int *svarevent, *methodevent;
+EXTERN double *timeevent, *valueevent;
+EXTERN int *svarevent, *methodevent;
 
 /* time delays */
-int interpolMethod;  /* for time-delays : 1 = hermite; 2=dense */
+EXTERN int interpolMethod;  /* for time-delays : 1 = hermite; 2=dense */
 
 /*============================================================================
  type definitions for C functions
 ============================================================================*/
 typedef void C_deriv_func_type(int*, double*, double*, double*, double*, int*);
-C_deriv_func_type* DLL_deriv_func;
+EXTERN C_deriv_func_type* DLL_deriv_func;
 
 typedef void C_res_func_type(double*, double*, double*, double*, double*,
                              int*, double*, int*);
-C_res_func_type* DLL_res_func;
+EXTERN C_res_func_type* DLL_res_func;
 
 
 /* this is for use in compiled code */
@@ -72,20 +76,20 @@ typedef void init_func_type (void (*)(int*, double*));
 /*============================================================================
   solver R- global functions 
 ============================================================================*/
-extern SEXP R_deriv_func;
-extern SEXP R_jac_func;
-extern SEXP R_jac_vec;
-extern SEXP R_root_func;
-extern SEXP R_event_func;
-extern SEXP R_envir;
+EXTERN SEXP R_deriv_func;
+EXTERN SEXP R_jac_func;
+EXTERN SEXP R_jac_vec;
+EXTERN SEXP R_root_func;
+EXTERN SEXP R_event_func;
+EXTERN SEXP R_envir;
 
 /* DAE globals */
-extern SEXP R_res_func;
-extern SEXP R_daejac_func;
-extern SEXP R_psol_func;
-extern SEXP R_mas_func;
+EXTERN SEXP R_res_func;
+EXTERN SEXP R_daejac_func;
+EXTERN SEXP R_psol_func;
+EXTERN SEXP R_mas_func;
 
-extern SEXP de_gparms;
+EXTERN SEXP de_gparms;
 SEXP getListElement(SEXP list, const char* str);
 
 SEXP getTimestep();
@@ -93,12 +97,6 @@ SEXP getTimestep();
 /*============================================================================ 
   C- utilities, functions 
 ============================================================================*/
-void init_N_Protect(void);
-void incr_N_Protect(void);
-long int save_N_Protected(void);
-void restore_N_Protected(long int);
-void unprotect_all(void);
-void my_unprotect(int);
 
 void lock_solver(void);
 void unlock_solver(void);
@@ -107,7 +105,7 @@ void returnearly (int, int, int);
 void terminate(int, int*, int, int, double *, int, int);
 
 /* declarations for initialisations */
-void initParms(SEXP Initfunc, SEXP Parms);
+// void initParms(SEXP Initfunc, SEXP Parms);
 void Initdeparms(int*, double*);
 void Initdeforc(int*, double*);
 void initOutR(int isDll, int *nout, int *ntot, int neq, SEXP nOut, SEXP Rpar, SEXP Ipar);
@@ -120,8 +118,8 @@ void sparsity3D(SEXP Type, int* iwork, int neq, int liw);
 void sparsity2Dmap(SEXP Type, int* iwork, int neq, int liw);  /* testing, since version 1.10.4*/
 void sparsity3Dmap(SEXP Type, int* iwork, int neq, int liw);  /* testing, since version 1.10.4*/
 void interactmap (int *ij, int nnz, int *iwork, int *ipres, int ival);
-void initglobals(int, int);
-void initdaeglobals(int, int);
+//void initglobals(int, int);
+//void initdaeglobals(int, int);
 
 /* the forcings and event functions */
 void updatedeforc(double*);
@@ -168,9 +166,10 @@ double interpolate(int i, int k, double t0, double t1, double t,
   Global variables for history arrays
 ==========================================*/
 
-int indexhist, indexlag, endreached, starthist;
-double *histvar, *histdvar, *histtime, *histhh, *histsave;
-int    *histord;
-int    histsize, offset;
-int    initialisehist, lyh, lhh, lo;
+EXTERN int indexhist, indexlag, endreached, starthist;
+EXTERN double *histvar, *histdvar, *histtime, *histhh, *histsave;
+EXTERN int    *histord;
+EXTERN int    histsize, offset;
+EXTERN int    initialisehist, lyh, lhh, lo;
 
+#undef EXTERN
